#! /usr/bin/env python
# -*- coding: koi8-r -*-

from __future__ import print_function

#
# Rus -> Lat transliteration (koi2lat and win2lat)
#

koi2lat_d = {
   "": "A",
   "": "B",
   "": "V",
   "": "G",
   "": "D",
   "": "E",
   "": "Zh",
   "": "Z",
   "": "I",
   "": "Y",
   "": "K",
   "": "L",
   "": "M",
   "": "N",
   "": "O",
   "": "P",
   "": "R",
   "": "S",
   "": "T",
   "": "U",
   "": "F",
   "": "H",
   "": "Ts",
   "": "Ch",
   "": "Sh",
   "": "Sh",
   "": "'",
   "": "'",
   "": "Y",
   "": "E",
   "": "Yu",
   "": "Ya",
   "": "a",
   "": "b",
   "": "v",
   "": "g",
   "": "d",
   "": "e",
   "": "zh",
   "": "z",
   "": "i",
   "": "y",
   "": "k",
   "": "l",
   "": "m",
   "": "n",
   "": "o",
   "": "p",
   "": "r",
   "": "s",
   "": "t",
   "": "u",
   "": "f",
   "": "h",
   "": "ts",
   "": "ch",
   "": "sh",
   "": "sh",
   "": "'",
   "": "'",
   "": "y",
   "": "e",
   "": "yu",
   "": "ya",
}

def make_xxx2lat(encoding="cp1251"):
   d = {}
   for k, v in koi2lat_d.items():
      if isinstance(k, bytes):
         k = k.decode("koi8-r")
      k = k.encode(encoding)
      d[k] = v
   return d


from ..lazy.dict import LazyDictInitFunc
win2lat_d = LazyDictInitFunc(make_xxx2lat, encoding="cp1251")


def rus2lat(instr, rus2lat_d = koi2lat_d):
   out = []
   for c in instr:
      c = rus2lat_d.get(c, c)
      if isinstance(c, bytes):
         c = c.decode('ascii')
      elif isinstance(c, int):
         c = chr(c)
      out.append(c.encode('ascii'))
   return b''.join(out)


koi2lat = rus2lat

def win2lat(instr):
   return rus2lat(instr, win2lat_d)


if __name__ == "__main__":
   Test = "  .  xyz   "
   print("Test:", Test)
   print(":", koi2lat(Test))
   if isinstance(Test, bytes):
      Test = Test.decode("cp1251")
   print(":", win2lat(Test.encode("cp1251")))
